You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ac...@apache.org on 2020/02/03 18:36:48 UTC

[camel-spring-boot] 01/04: Added a camel-aws2-msk starter

This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel-spring-boot.git

commit 95523c68ffcfba58276792d30ee3417633c8433d
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Mon Feb 3 13:40:59 2020 +0100

    Added a camel-aws2-msk starter
---
 .../camel/springboot/catalog/components.properties |   1 +
 .../springboot/catalog/components/aws2-mq.json     |   4 +-
 .../components/{aws2-mq.json => aws2-msk.json}     |  34 ++--
 .../camel/springboot/catalog/components/weka.json  |   4 +-
 .../springboot/catalog/dataformats/xstream.json    |   4 +-
 .../camel/springboot/catalog/others.properties     |   1 +
 .../camel/springboot/catalog/others/cbor.json      |  12 ++
 .../mq/springboot/MQ2ComponentConfiguration.java   |   8 +-
 components-starter/camel-aws2-msk-starter/pom.xml  |  61 +++++++
 .../springboot/MSK2ComponentAutoConfiguration.java | 128 +++++++++++++
 .../springboot/MSK2ComponentConfiguration.java}    |  63 ++++---
 .../src/main/resources/META-INF/LICENSE.txt        | 203 +++++++++++++++++++++
 .../src/main/resources/META-INF/NOTICE.txt         |  11 ++
 .../src/main/resources/META-INF/spring.factories   |  19 ++
 .../src/main/resources/META-INF/spring.provides    |  17 ++
 .../springboot/XStreamDataFormatConfiguration.java |   4 +-
 components-starter/pom.xml                         |   1 +
 tooling/camel-spring-boot-dependencies/pom.xml     |  10 +
 18 files changed, 524 insertions(+), 61 deletions(-)

diff --git a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components.properties b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components.properties
index 068b3a0..8019a0b 100644
--- a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components.properties
+++ b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components.properties
@@ -39,6 +39,7 @@ aws-translate
 aws2-ecs
 aws2-eks
 aws2-mq
+aws2-msk
 aws2-translate
 azure-blob
 azure-queue
diff --git a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-mq.json b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-mq.json
index 9ee72e7..74e7b78 100644
--- a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-mq.json
+++ b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-mq.json
@@ -5,7 +5,7 @@
     "extendsScheme": "",
     "syntax": "aws2-mq:label",
     "title": "AWS 2 MQ",
-    "description": "The aws-mq is used for managing Amazon MQ instances.",
+    "description": "The aws2-mq is used for managing Amazon MQ instances.",
     "label": "cloud,management",
     "deprecated": false,
     "async": false,
@@ -35,7 +35,7 @@
     "proxyHost": { "kind": "parameter", "displayName": "Proxy Host", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "To define a proxy host when instantiating the MQ client" },
     "proxyPort": { "kind": "parameter", "displayName": "Proxy Port", "group": "producer", "label": "producer", "required": false, "type": "integer", "javaType": "java.lang.Integer", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "To define a proxy port when instantiating the MQ client" },
     "proxyProtocol": { "kind": "parameter", "displayName": "Proxy Protocol", "group": "producer", "label": "", "required": false, "type": "object", "javaType": "software.amazon.awssdk.core.Protocol", "enum": [ "HTTP", "HTTPS" ], "deprecated": false, "secret": false, "defaultValue": "HTTPS", "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "To define a proxy protocol when instantiating the MQ client" },
-    "region": { "kind": "parameter", "displayName": "Region", "group": "producer", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "The region in which MQ client needs to work. When using this parameter, the configuration will expect the capitalized name of the region (for example AP_EAST [...]
+    "region": { "kind": "parameter", "displayName": "Region", "group": "producer", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "The region in which MQ client needs to work. When using this parameter, the configuration will expect the lowercase name of the region (for example ap-east-1 [...]
     "secretKey": { "kind": "parameter", "displayName": "Secret Key", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": true, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "Amazon AWS Secret Key" },
     "basicPropertyBinding": { "kind": "parameter", "displayName": "Basic Property Binding", "group": "advanced", "label": "advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "secret": false, "defaultValue": false, "description": "Whether the endpoint should use basic property binding (Camel 2.x) or the newer property binding with additional capabilities" },
     "synchronous": { "kind": "parameter", "displayName": "Synchronous", "group": "advanced", "label": "advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "secret": false, "defaultValue": "false", "description": "Sets whether synchronous processing should be strictly used, or Camel is allowed to use asynchronous processing (if supported)." }
diff --git a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-mq.json b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-msk.json
similarity index 71%
copy from camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-mq.json
copy to camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-msk.json
index 9ee72e7..1a20b2e 100644
--- a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-mq.json
+++ b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/aws2-msk.json
@@ -1,42 +1,42 @@
 {
   "component": {
     "kind": "component",
-    "scheme": "aws2-mq",
+    "scheme": "aws2-msk",
     "extendsScheme": "",
-    "syntax": "aws2-mq:label",
-    "title": "AWS 2 MQ",
-    "description": "The aws-mq is used for managing Amazon MQ instances.",
+    "syntax": "aws2-msk:label",
+    "title": "AWS 2 MSK",
+    "description": "The aws2-msk is used for managing Amazon MSK",
     "label": "cloud,management",
     "deprecated": false,
     "async": false,
     "consumerOnly": false,
     "producerOnly": true,
     "lenientProperties": false,
-    "javaType": "org.apache.camel.component.aws2.mq.MQ2Component",
+    "javaType": "org.apache.camel.component.aws2.msk.MSK2Component",
     "firstVersion": "3.1.0",
     "groupId": "org.apache.camel.springboot",
-    "artifactId": "camel-aws2-mq-starter",
+    "artifactId": "camel-aws2-msk-starter",
     "version": "3.1.0-SNAPSHOT"
   },
   "componentProperties": {
-    "configuration": { "kind": "property", "displayName": "Configuration", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "org.apache.camel.component.aws2.mq.MQ2Configuration", "deprecated": false, "secret": false, "description": "The AWS MQ default configuration" },
+    "configuration": { "kind": "property", "displayName": "Configuration", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "org.apache.camel.component.aws2.msk.MSK2Configuration", "deprecated": false, "secret": false, "description": "The AWS MSK default configuration" },
     "accessKey": { "kind": "property", "displayName": "Access Key", "group": "producer", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "description": "Amazon AWS Access Key" },
     "secretKey": { "kind": "property", "displayName": "Secret Key", "group": "producer", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "description": "Amazon AWS Secret Key" },
-    "region": { "kind": "property", "displayName": "Region", "group": "producer", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "description": "The region in which MQ client needs to work" },
+    "region": { "kind": "property", "displayName": "Region", "group": "producer", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "description": "The region in which MSK client needs to work" },
     "basicPropertyBinding": { "kind": "property", "displayName": "Basic Property Binding", "group": "advanced", "label": "advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "secret": false, "defaultValue": false, "description": "Whether the component should use basic property binding (Camel 2.x) or the newer property binding with additional capabilities" },
     "lazyStartProducer": { "kind": "property", "displayName": "Lazy Start Producer", "group": "producer", "label": "producer", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "secret": false, "defaultValue": false, "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a producer may otherwise fail during starting and cause the r [...]
   },
   "properties": {
-    "label": { "kind": "path", "displayName": "Label", "group": "producer", "label": "", "required": true, "type": "string", "javaType": "java.lang.String", "deprecated": false, "deprecationNote": "", "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "Logical name" },
-    "accessKey": { "kind": "parameter", "displayName": "Access Key", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": true, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "Amazon AWS Access Key" },
-    "amazonMqClient": { "kind": "parameter", "displayName": "Amazon Mq Client", "group": "producer", "label": "producer", "required": false, "type": "object", "javaType": "software.amazon.awssdk.services.mq.MqClient", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "To use a existing configured AmazonMQClient as client" },
+    "label": { "kind": "path", "displayName": "Label", "group": "producer", "label": "", "required": true, "type": "string", "javaType": "java.lang.String", "deprecated": false, "deprecationNote": "", "secret": false, "configurationClass": "org.apache.camel.component.aws2.msk.MSK2Configuration", "configurationField": "configuration", "description": "Logical name" },
+    "accessKey": { "kind": "parameter", "displayName": "Access Key", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": true, "configurationClass": "org.apache.camel.component.aws2.msk.MSK2Configuration", "configurationField": "configuration", "description": "Amazon AWS Access Key" },
     "lazyStartProducer": { "kind": "parameter", "displayName": "Lazy Start Producer", "group": "producer", "label": "producer", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "secret": false, "defaultValue": false, "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a producer may otherwise fail during starting and cause the  [...]
-    "operation": { "kind": "parameter", "displayName": "Operation", "group": "producer", "label": "producer", "required": true, "type": "object", "javaType": "org.apache.camel.component.aws2.mq.MQ2Operations", "enum": [ "listBrokers", "createBroker", "deleteBroker", "rebootBroker", "updateBroker", "describeBroker" ], "deprecated": false, "deprecationNote": "", "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuratio [...]
-    "proxyHost": { "kind": "parameter", "displayName": "Proxy Host", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "To define a proxy host when instantiating the MQ client" },
-    "proxyPort": { "kind": "parameter", "displayName": "Proxy Port", "group": "producer", "label": "producer", "required": false, "type": "integer", "javaType": "java.lang.Integer", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "To define a proxy port when instantiating the MQ client" },
-    "proxyProtocol": { "kind": "parameter", "displayName": "Proxy Protocol", "group": "producer", "label": "", "required": false, "type": "object", "javaType": "software.amazon.awssdk.core.Protocol", "enum": [ "HTTP", "HTTPS" ], "deprecated": false, "secret": false, "defaultValue": "HTTPS", "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "To define a proxy protocol when instantiating the MQ client" },
-    "region": { "kind": "parameter", "displayName": "Region", "group": "producer", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "The region in which MQ client needs to work. When using this parameter, the configuration will expect the capitalized name of the region (for example AP_EAST [...]
-    "secretKey": { "kind": "parameter", "displayName": "Secret Key", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": true, "configurationClass": "org.apache.camel.component.aws2.mq.MQ2Configuration", "configurationField": "configuration", "description": "Amazon AWS Secret Key" },
+    "mskClient": { "kind": "parameter", "displayName": "Msk Client", "group": "producer", "label": "producer", "required": false, "type": "object", "javaType": "software.amazon.awssdk.services.kafka.KafkaClient", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.msk.MSK2Configuration", "configurationField": "configuration", "description": "To use a existing configured AWS MSK as client" },
+    "operation": { "kind": "parameter", "displayName": "Operation", "group": "producer", "label": "producer", "required": true, "type": "object", "javaType": "org.apache.camel.component.aws2.msk.MSK2Operations", "enum": [ "listClusters", "createCluster", "deleteCluster", "describeCluster" ], "deprecated": false, "deprecationNote": "", "secret": false, "configurationClass": "org.apache.camel.component.aws2.msk.MSK2Configuration", "configurationField": "configuration", "description": "The  [...]
+    "proxyHost": { "kind": "parameter", "displayName": "Proxy Host", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.msk.MSK2Configuration", "configurationField": "configuration", "description": "To define a proxy host when instantiating the MSK client" },
+    "proxyPort": { "kind": "parameter", "displayName": "Proxy Port", "group": "producer", "label": "producer", "required": false, "type": "integer", "javaType": "java.lang.Integer", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.msk.MSK2Configuration", "configurationField": "configuration", "description": "To define a proxy port when instantiating the MSK client" },
+    "proxyProtocol": { "kind": "parameter", "displayName": "Proxy Protocol", "group": "producer", "label": "", "required": false, "type": "object", "javaType": "software.amazon.awssdk.core.Protocol", "enum": [ "HTTP", "HTTPS" ], "deprecated": false, "secret": false, "defaultValue": "HTTPS", "configurationClass": "org.apache.camel.component.aws2.msk.MSK2Configuration", "configurationField": "configuration", "description": "To define a proxy protocol when instantiating the MSK client" },
+    "region": { "kind": "parameter", "displayName": "Region", "group": "producer", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.msk.MSK2Configuration", "configurationField": "configuration", "description": "The region in which MSK client needs to work. When using this parameter, the configuration will expect the lowercase name of the region (for example ap-eas [...]
+    "secretKey": { "kind": "parameter", "displayName": "Secret Key", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": true, "configurationClass": "org.apache.camel.component.aws2.msk.MSK2Configuration", "configurationField": "configuration", "description": "Amazon AWS Secret Key" },
     "basicPropertyBinding": { "kind": "parameter", "displayName": "Basic Property Binding", "group": "advanced", "label": "advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "secret": false, "defaultValue": false, "description": "Whether the endpoint should use basic property binding (Camel 2.x) or the newer property binding with additional capabilities" },
     "synchronous": { "kind": "parameter", "displayName": "Synchronous", "group": "advanced", "label": "advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "secret": false, "defaultValue": "false", "description": "Sets whether synchronous processing should be strictly used, or Camel is allowed to use asynchronous processing (if supported)." }
   }
diff --git a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/weka.json b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/weka.json
index d6c3b67..088c61e 100644
--- a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/weka.json
+++ b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/weka.json
@@ -3,10 +3,10 @@
     "kind": "component",
     "scheme": "weka",
     "extendsScheme": "",
-    "syntax": "weka:cmd?options",
+    "syntax": "weka:cmd",
     "title": "Weka",
     "description": "The camel-weka component provides Data Mining functionality through Weka.",
-    "label": "data mining",
+    "label": "Datamining",
     "deprecated": false,
     "async": false,
     "consumerOnly": false,
diff --git a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/dataformats/xstream.json b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/dataformats/xstream.json
index 381bcfa..82806ea 100644
--- a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/dataformats/xstream.json
+++ b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/dataformats/xstream.json
@@ -4,7 +4,7 @@
     "name": "xstream",
     "modelName": "xstream",
     "title": "XStream",
-    "description": "XSTream data format is used for unmarshal a XML payload to POJO or to marshal POJO back to XML payload.",
+    "description": "XStream data format is used for unmarshal a XML payload to POJO or to marshal POJO back to XML payload.",
     "deprecated": false,
     "deprecationNote": "dataformat,transformation,xml,json",
     "firstVersion": "1.3.0",
@@ -16,7 +16,7 @@
     "version": "3.1.0-SNAPSHOT"
   },
   "properties": {
-    "permissions": { "kind": "attribute", "displayName": "Permissions", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "description": "Adds permissions that controls which Java packages and classes XStream is allowed to use during unmarshal from xml\/json to Java beans. A permission must be configured either here or globally using a JVM system property. The permission can be specified in a syntax where a plus sign is allow, and  [...]
+    "permissions": { "kind": "attribute", "displayName": "Permissions", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "description": "Adds permissions that controls which Java packages and classes XStream is allowed to use during unmarshal from xml\/json to Java beans. A permission must be configured either here or globally using a JVM system property. The permission can be specified in a syntax where a plus sign is allow, and  [...]
     "encoding": { "kind": "attribute", "displayName": "Encoding", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "description": "Sets the encoding to use" },
     "driver": { "kind": "attribute", "displayName": "Driver", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "description": "To use a custom XStream driver. The instance must be of type com.thoughtworks.xstream.io.HierarchicalStreamDriver" },
     "driverRef": { "kind": "attribute", "displayName": "Driver Ref", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "secret": false, "description": "To refer to a custom XStream driver to lookup in the registry. The instance must be of type com.thoughtworks.xstream.io.HierarchicalStreamDriver" },
diff --git a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/others.properties b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/others.properties
index 7385e16..b8331aa 100644
--- a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/others.properties
+++ b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/others.properties
@@ -1,5 +1,6 @@
 as2
 aws-xray
+cbor
 cxf-transport
 debezium-common
 http-common
diff --git a/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/others/cbor.json b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/others/cbor.json
new file mode 100644
index 0000000..bfdeddc
--- /dev/null
+++ b/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/others/cbor.json
@@ -0,0 +1,12 @@
+{
+  "other": {
+    "kind": "other",
+    "name": "cbor",
+    "title": "Cbor",
+    "description": "Camel Cbor Support",
+    "deprecated": false,
+    "groupId": "org.apache.camel.springboot",
+    "artifactId": "camel-cbor-starter",
+    "version": "3.1.0-SNAPSHOT"
+  }
+}
diff --git a/components-starter/camel-aws2-mq-starter/src/main/java/org/apache/camel/component/aws2/mq/springboot/MQ2ComponentConfiguration.java b/components-starter/camel-aws2-mq-starter/src/main/java/org/apache/camel/component/aws2/mq/springboot/MQ2ComponentConfiguration.java
index 812763c..2c17569 100644
--- a/components-starter/camel-aws2-mq-starter/src/main/java/org/apache/camel/component/aws2/mq/springboot/MQ2ComponentConfiguration.java
+++ b/components-starter/camel-aws2-mq-starter/src/main/java/org/apache/camel/component/aws2/mq/springboot/MQ2ComponentConfiguration.java
@@ -24,7 +24,7 @@ import software.amazon.awssdk.core.Protocol;
 import software.amazon.awssdk.services.mq.MqClient;
 
 /**
- * The aws-mq is used for managing Amazon MQ instances.
+ * The aws2-mq is used for managing Amazon MQ instances.
  * 
  * Generated by camel-package-maven-plugin - do not edit this file!
  */
@@ -150,9 +150,9 @@ public class MQ2ComponentConfiguration
         private Protocol proxyProtocol = Protocol.HTTPS;
         /**
          * The region in which MQ client needs to work. When using this
-         * parameter, the configuration will expect the capitalized name of the
-         * region (for example AP_EAST_1) You'll need to use the name
-         * Regions.EU_WEST_1.name()
+         * parameter, the configuration will expect the lowercase name of the
+         * region (for example ap-east-1) You'll need to use the name
+         * Region.EU_WEST_1.id()
          */
         private String region;
         /**
diff --git a/components-starter/camel-aws2-msk-starter/pom.xml b/components-starter/camel-aws2-msk-starter/pom.xml
new file mode 100644
index 0000000..44163ae
--- /dev/null
+++ b/components-starter/camel-aws2-msk-starter/pom.xml
@@ -0,0 +1,61 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+
+    Licensed to the Apache Software Foundation (ASF) under one or more
+    contributor license agreements.  See the NOTICE file distributed with
+    this work for additional information regarding copyright ownership.
+    The ASF licenses this file to You under the Apache License, Version 2.0
+    (the "License"); you may not use this file except in compliance with
+    the License.  You may obtain a copy of the License at
+
+         http://www.apache.org/licenses/LICENSE-2.0
+
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
+
+-->
+<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
+  <modelVersion>4.0.0</modelVersion>
+  <parent>
+    <groupId>org.apache.camel.springboot</groupId>
+    <artifactId>components-starter</artifactId>
+    <version>3.1.0-SNAPSHOT</version>
+  </parent>
+  <artifactId>camel-aws2-msk-starter</artifactId>
+  <packaging>jar</packaging>
+  <!--    <name>Camel Spring Boot :: Starters :: Dozer</name>-->
+  <!--    <description>Spring-Boot Starter for Camel Support for the Dozer type conversion framework</description>-->
+  <dependencies>
+    <dependency>
+      <groupId>org.springframework.boot</groupId>
+      <artifactId>spring-boot-starter</artifactId>
+      <version>${spring-boot-version}</version>
+    </dependency>
+    <dependency>
+      <groupId>org.apache.camel</groupId>
+      <artifactId>camel-aws2-msk</artifactId>
+      <version>${camel-version}</version>
+      <!--START OF GENERATED CODE-->
+      <exclusions>
+        <exclusion>
+          <groupId>commons-logging</groupId>
+          <artifactId>commons-logging</artifactId>
+        </exclusion>
+      </exclusions>
+      <!--END OF GENERATED CODE-->
+    </dependency>
+    <!--START OF GENERATED CODE-->
+    <dependency>
+      <groupId>org.apache.camel.springboot</groupId>
+      <artifactId>camel-core-starter</artifactId>
+    </dependency>
+    <dependency>
+      <groupId>org.apache.camel.springboot</groupId>
+      <artifactId>camel-spring-boot-starter</artifactId>
+    </dependency>
+    <!--END OF GENERATED CODE-->
+  </dependencies>
+</project>
diff --git a/components-starter/camel-aws2-msk-starter/src/main/java/org/apache/camel/component/aws2/msk/springboot/MSK2ComponentAutoConfiguration.java b/components-starter/camel-aws2-msk-starter/src/main/java/org/apache/camel/component/aws2/msk/springboot/MSK2ComponentAutoConfiguration.java
new file mode 100644
index 0000000..276a265
--- /dev/null
+++ b/components-starter/camel-aws2-msk-starter/src/main/java/org/apache/camel/component/aws2/msk/springboot/MSK2ComponentAutoConfiguration.java
@@ -0,0 +1,128 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.camel.component.aws2.msk.springboot;
+
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import javax.annotation.Generated;
+import org.apache.camel.CamelContext;
+import org.apache.camel.component.aws2.msk.MSK2Component;
+import org.apache.camel.spi.ComponentCustomizer;
+import org.apache.camel.spi.HasId;
+import org.apache.camel.spring.boot.CamelAutoConfiguration;
+import org.apache.camel.spring.boot.ComponentConfigurationProperties;
+import org.apache.camel.spring.boot.util.CamelPropertiesHelper;
+import org.apache.camel.spring.boot.util.ConditionalOnCamelContextAndAutoConfigurationBeans;
+import org.apache.camel.spring.boot.util.GroupCondition;
+import org.apache.camel.spring.boot.util.HierarchicalPropertiesEvaluator;
+import org.apache.camel.support.IntrospectionSupport;
+import org.apache.camel.util.ObjectHelper;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.boot.autoconfigure.AutoConfigureAfter;
+import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
+import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
+import org.springframework.boot.context.properties.EnableConfigurationProperties;
+import org.springframework.context.ApplicationContext;
+import org.springframework.context.annotation.Bean;
+import org.springframework.context.annotation.Conditional;
+import org.springframework.context.annotation.Configuration;
+import org.springframework.context.annotation.Lazy;
+
+/**
+ * Generated by camel-package-maven-plugin - do not edit this file!
+ */
+@Generated("org.apache.camel.springboot.maven.SpringBootAutoConfigurationMojo")
+@Configuration
+@Conditional({ConditionalOnCamelContextAndAutoConfigurationBeans.class,
+        MSK2ComponentAutoConfiguration.GroupConditions.class})
+@AutoConfigureAfter(CamelAutoConfiguration.class)
+@EnableConfigurationProperties({ComponentConfigurationProperties.class,
+        MSK2ComponentConfiguration.class})
+public class MSK2ComponentAutoConfiguration {
+
+    private static final Logger LOGGER = LoggerFactory
+            .getLogger(MSK2ComponentAutoConfiguration.class);
+    @Autowired
+    private ApplicationContext applicationContext;
+    @Autowired
+    private CamelContext camelContext;
+    @Autowired
+    private MSK2ComponentConfiguration configuration;
+    @Autowired(required = false)
+    private List<ComponentCustomizer<MSK2Component>> customizers;
+
+    static class GroupConditions extends GroupCondition {
+        public GroupConditions() {
+            super("camel.component", "camel.component.aws2-msk");
+        }
+    }
+
+    @Lazy
+    @Bean(name = "aws2-msk-component")
+    @ConditionalOnMissingBean(MSK2Component.class)
+    public MSK2Component configureMSK2Component() throws Exception {
+        MSK2Component component = new MSK2Component();
+        component.setCamelContext(camelContext);
+        Map<String, Object> parameters = new HashMap<>();
+        IntrospectionSupport.getProperties(configuration, parameters, null,
+                false);
+        for (Map.Entry<String, Object> entry : parameters.entrySet()) {
+            Object value = entry.getValue();
+            Class<?> paramClass = value.getClass();
+            if (paramClass.getName().endsWith("NestedConfiguration")) {
+                Class nestedClass = null;
+                try {
+                    nestedClass = (Class) paramClass.getDeclaredField(
+                            "CAMEL_NESTED_CLASS").get(null);
+                    HashMap<String, Object> nestedParameters = new HashMap<>();
+                    IntrospectionSupport.getProperties(value, nestedParameters,
+                            null, false);
+                    Object nestedProperty = nestedClass.newInstance();
+                    CamelPropertiesHelper.setCamelProperties(camelContext,
+                            nestedProperty, nestedParameters, false);
+                    entry.setValue(nestedProperty);
+                } catch (NoSuchFieldException e) {
+                }
+            }
+        }
+        CamelPropertiesHelper.setCamelProperties(camelContext, component,
+                parameters, false);
+        if (ObjectHelper.isNotEmpty(customizers)) {
+            for (ComponentCustomizer<MSK2Component> customizer : customizers) {
+                boolean useCustomizer = (customizer instanceof HasId)
+                        ? HierarchicalPropertiesEvaluator.evaluate(
+                                applicationContext.getEnvironment(),
+                                "camel.component.customizer",
+                                "camel.component.aws2-msk.customizer",
+                                ((HasId) customizer).getId())
+                        : HierarchicalPropertiesEvaluator.evaluate(
+                                applicationContext.getEnvironment(),
+                                "camel.component.customizer",
+                                "camel.component.aws2-msk.customizer");
+                if (useCustomizer) {
+                    LOGGER.debug("Configure component {}, with customizer {}",
+                            component, customizer);
+                    customizer.customize(component);
+                }
+            }
+        }
+        return component;
+    }
+}
\ No newline at end of file
diff --git a/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/LICENSE.txt b/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/LICENSE.txt
new file mode 100644
index 0000000..6b0b127
--- /dev/null
+++ b/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/LICENSE.txt
@@ -0,0 +1,203 @@
+
+                                 Apache License
+                           Version 2.0, January 2004
+                        http://www.apache.org/licenses/
+
+   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION
+
+   1. Definitions.
+
+      "License" shall mean the terms and conditions for use, reproduction,
+      and distribution as defined by Sections 1 through 9 of this document.
+
+      "Licensor" shall mean the copyright owner or entity authorized by
+      the copyright owner that is granting the License.
+
+      "Legal Entity" shall mean the union of the acting entity and all
+      other entities that control, are controlled by, or are under common
+      control with that entity. For the purposes of this definition,
+      "control" means (i) the power, direct or indirect, to cause the
+      direction or management of such entity, whether by contract or
+      otherwise, or (ii) ownership of fifty percent (50%) or more of the
+      outstanding shares, or (iii) beneficial ownership of such entity.
+
+      "You" (or "Your") shall mean an individual or Legal Entity
+      exercising permissions granted by this License.
+
+      "Source" form shall mean the preferred form for making modifications,
+      including but not limited to software source code, documentation
+      source, and configuration files.
+
+      "Object" form shall mean any form resulting from mechanical
+      transformation or translation of a Source form, including but
+      not limited to compiled object code, generated documentation,
+      and conversions to other media types.
+
+      "Work" shall mean the work of authorship, whether in Source or
+      Object form, made available under the License, as indicated by a
+      copyright notice that is included in or attached to the work
+      (an example is provided in the Appendix below).
+
+      "Derivative Works" shall mean any work, whether in Source or Object
+      form, that is based on (or derived from) the Work and for which the
+      editorial revisions, annotations, elaborations, or other modifications
+      represent, as a whole, an original work of authorship. For the purposes
+      of this License, Derivative Works shall not include works that remain
+      separable from, or merely link (or bind by name) to the interfaces of,
+      the Work and Derivative Works thereof.
+
+      "Contribution" shall mean any work of authorship, including
+      the original version of the Work and any modifications or additions
+      to that Work or Derivative Works thereof, that is intentionally
+      submitted to Licensor for inclusion in the Work by the copyright owner
+      or by an individual or Legal Entity authorized to submit on behalf of
+      the copyright owner. For the purposes of this definition, "submitted"
+      means any form of electronic, verbal, or written communication sent
+      to the Licensor or its representatives, including but not limited to
+      communication on electronic mailing lists, source code control systems,
+      and issue tracking systems that are managed by, or on behalf of, the
+      Licensor for the purpose of discussing and improving the Work, but
+      excluding communication that is conspicuously marked or otherwise
+      designated in writing by the copyright owner as "Not a Contribution."
+
+      "Contributor" shall mean Licensor and any individual or Legal Entity
+      on behalf of whom a Contribution has been received by Licensor and
+      subsequently incorporated within the Work.
+
+   2. Grant of Copyright License. Subject to the terms and conditions of
+      this License, each Contributor hereby grants to You a perpetual,
+      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+      copyright license to reproduce, prepare Derivative Works of,
+      publicly display, publicly perform, sublicense, and distribute the
+      Work and such Derivative Works in Source or Object form.
+
+   3. Grant of Patent License. Subject to the terms and conditions of
+      this License, each Contributor hereby grants to You a perpetual,
+      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+      (except as stated in this section) patent license to make, have made,
+      use, offer to sell, sell, import, and otherwise transfer the Work,
+      where such license applies only to those patent claims licensable
+      by such Contributor that are necessarily infringed by their
+      Contribution(s) alone or by combination of their Contribution(s)
+      with the Work to which such Contribution(s) was submitted. If You
+      institute patent litigation against any entity (including a
+      cross-claim or counterclaim in a lawsuit) alleging that the Work
+      or a Contribution incorporated within the Work constitutes direct
+      or contributory patent infringement, then any patent licenses
+      granted to You under this License for that Work shall terminate
+      as of the date such litigation is filed.
+
+   4. Redistribution. You may reproduce and distribute copies of the
+      Work or Derivative Works thereof in any medium, with or without
+      modifications, and in Source or Object form, provided that You
+      meet the following conditions:
+
+      (a) You must give any other recipients of the Work or
+          Derivative Works a copy of this License; and
+
+      (b) You must cause any modified files to carry prominent notices
+          stating that You changed the files; and
+
+      (c) You must retain, in the Source form of any Derivative Works
+          that You distribute, all copyright, patent, trademark, and
+          attribution notices from the Source form of the Work,
+          excluding those notices that do not pertain to any part of
+          the Derivative Works; and
+
+      (d) If the Work includes a "NOTICE" text file as part of its
+          distribution, then any Derivative Works that You distribute must
+          include a readable copy of the attribution notices contained
+          within such NOTICE file, excluding those notices that do not
+          pertain to any part of the Derivative Works, in at least one
+          of the following places: within a NOTICE text file distributed
+          as part of the Derivative Works; within the Source form or
+          documentation, if provided along with the Derivative Works; or,
+          within a display generated by the Derivative Works, if and
+          wherever such third-party notices normally appear. The contents
+          of the NOTICE file are for informational purposes only and
+          do not modify the License. You may add Your own attribution
+          notices within Derivative Works that You distribute, alongside
+          or as an addendum to the NOTICE text from the Work, provided
+          that such additional attribution notices cannot be construed
+          as modifying the License.
+
+      You may add Your own copyright statement to Your modifications and
+      may provide additional or different license terms and conditions
+      for use, reproduction, or distribution of Your modifications, or
+      for any such Derivative Works as a whole, provided Your use,
+      reproduction, and distribution of the Work otherwise complies with
+      the conditions stated in this License.
+
+   5. Submission of Contributions. Unless You explicitly state otherwise,
+      any Contribution intentionally submitted for inclusion in the Work
+      by You to the Licensor shall be under the terms and conditions of
+      this License, without any additional terms or conditions.
+      Notwithstanding the above, nothing herein shall supersede or modify
+      the terms of any separate license agreement you may have executed
+      with Licensor regarding such Contributions.
+
+   6. Trademarks. This License does not grant permission to use the trade
+      names, trademarks, service marks, or product names of the Licensor,
+      except as required for reasonable and customary use in describing the
+      origin of the Work and reproducing the content of the NOTICE file.
+
+   7. Disclaimer of Warranty. Unless required by applicable law or
+      agreed to in writing, Licensor provides the Work (and each
+      Contributor provides its Contributions) on an "AS IS" BASIS,
+      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+      implied, including, without limitation, any warranties or conditions
+      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
+      PARTICULAR PURPOSE. You are solely responsible for determining the
+      appropriateness of using or redistributing the Work and assume any
+      risks associated with Your exercise of permissions under this License.
+
+   8. Limitation of Liability. In no event and under no legal theory,
+      whether in tort (including negligence), contract, or otherwise,
+      unless required by applicable law (such as deliberate and grossly
+      negligent acts) or agreed to in writing, shall any Contributor be
+      liable to You for damages, including any direct, indirect, special,
+      incidental, or consequential damages of any character arising as a
+      result of this License or out of the use or inability to use the
+      Work (including but not limited to damages for loss of goodwill,
+      work stoppage, computer failure or malfunction, or any and all
+      other commercial damages or losses), even if such Contributor
+      has been advised of the possibility of such damages.
+
+   9. Accepting Warranty or Additional Liability. While redistributing
+      the Work or Derivative Works thereof, You may choose to offer,
+      and charge a fee for, acceptance of support, warranty, indemnity,
+      or other liability obligations and/or rights consistent with this
+      License. However, in accepting such obligations, You may act only
+      on Your own behalf and on Your sole responsibility, not on behalf
+      of any other Contributor, and only if You agree to indemnify,
+      defend, and hold each Contributor harmless for any liability
+      incurred by, or claims asserted against, such Contributor by reason
+      of your accepting any such warranty or additional liability.
+
+   END OF TERMS AND CONDITIONS
+
+   APPENDIX: How to apply the Apache License to your work.
+
+      To apply the Apache License to your work, attach the following
+      boilerplate notice, with the fields enclosed by brackets "[]"
+      replaced with your own identifying information. (Don't include
+      the brackets!)  The text should be enclosed in the appropriate
+      comment syntax for the file format. We also recommend that a
+      file or class name and description of purpose be included on the
+      same "printed page" as the copyright notice for easier
+      identification within third-party archives.
+
+   Copyright [yyyy] [name of copyright owner]
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
diff --git a/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/NOTICE.txt b/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/NOTICE.txt
new file mode 100644
index 0000000..2e215bf
--- /dev/null
+++ b/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/NOTICE.txt
@@ -0,0 +1,11 @@
+   =========================================================================
+   ==  NOTICE file corresponding to the section 4 d of                    ==
+   ==  the Apache License, Version 2.0,                                   ==
+   ==  in this case for the Apache Camel distribution.                    ==
+   =========================================================================
+
+   This product includes software developed by
+   The Apache Software Foundation (http://www.apache.org/).
+
+   Please read the different LICENSE files present in the licenses directory of
+   this distribution.
diff --git a/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/spring.factories b/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/spring.factories
new file mode 100644
index 0000000..f073c6d
--- /dev/null
+++ b/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/spring.factories
@@ -0,0 +1,19 @@
+## ---------------------------------------------------------------------------
+## Licensed to the Apache Software Foundation (ASF) under one or more
+## contributor license agreements.  See the NOTICE file distributed with
+## this work for additional information regarding copyright ownership.
+## The ASF licenses this file to You under the Apache License, Version 2.0
+## (the "License"); you may not use this file except in compliance with
+## the License.  You may obtain a copy of the License at
+##
+##      http://www.apache.org/licenses/LICENSE-2.0
+##
+## Unless required by applicable law or agreed to in writing, software
+## distributed under the License is distributed on an "AS IS" BASIS,
+## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+## See the License for the specific language governing permissions and
+## limitations under the License.
+## ---------------------------------------------------------------------------
+
+org.springframework.boot.autoconfigure.EnableAutoConfiguration=\
+org.apache.camel.component.aws2.msk.springboot.MSK2ComponentAutoConfiguration
diff --git a/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/spring.provides b/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/spring.provides
new file mode 100644
index 0000000..9f529b2
--- /dev/null
+++ b/components-starter/camel-aws2-msk-starter/src/main/resources/META-INF/spring.provides
@@ -0,0 +1,17 @@
+## ---------------------------------------------------------------------------
+## Licensed to the Apache Software Foundation (ASF) under one or more
+## contributor license agreements.  See the NOTICE file distributed with
+## this work for additional information regarding copyright ownership.
+## The ASF licenses this file to You under the Apache License, Version 2.0
+## (the "License"); you may not use this file except in compliance with
+## the License.  You may obtain a copy of the License at
+##
+##      http://www.apache.org/licenses/LICENSE-2.0
+##
+## Unless required by applicable law or agreed to in writing, software
+## distributed under the License is distributed on an "AS IS" BASIS,
+## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+## See the License for the specific language governing permissions and
+## limitations under the License.
+## ---------------------------------------------------------------------------
+provides: camel-aws2-msk
diff --git a/components-starter/camel-xstream-starter/src/main/java/org/apache/camel/dataformat/xstream/springboot/XStreamDataFormatConfiguration.java b/components-starter/camel-xstream-starter/src/main/java/org/apache/camel/dataformat/xstream/springboot/XStreamDataFormatConfiguration.java
index a478336..741afaf 100644
--- a/components-starter/camel-xstream-starter/src/main/java/org/apache/camel/dataformat/xstream/springboot/XStreamDataFormatConfiguration.java
+++ b/components-starter/camel-xstream-starter/src/main/java/org/apache/camel/dataformat/xstream/springboot/XStreamDataFormatConfiguration.java
@@ -23,7 +23,7 @@ import org.apache.camel.spring.boot.DataFormatConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 
 /**
- * XSTream data format is used for unmarshal a XML payload to POJO or to marshal
+ * XStream data format is used for unmarshal a XML payload to POJO or to marshal
  * POJO back to XML payload.
  * 
  * Generated by camel-package-maven-plugin - do not edit this file!
@@ -45,7 +45,7 @@ public class XStreamDataFormatConfiguration
      * must be configured either here or globally using a JVM system property.
      * The permission can be specified in a syntax where a plus sign is allow,
      * and minus sign is deny. Wildcards is supported by using . as prefix. For
-     * example to allow com.foo and all subpackages then specfy com.foo..
+     * example to allow com.foo and all subpackages then specify com.foo..
      * Multiple permissions can be configured separated by comma, such as
      * com.foo.,-com.foo.bar.MySecretBean. The following default permission is
      * always included: -,java.lang.,java.util. unless its overridden by
diff --git a/components-starter/pom.xml b/components-starter/pom.xml
index 8fabe01..633b879 100644
--- a/components-starter/pom.xml
+++ b/components-starter/pom.xml
@@ -137,6 +137,7 @@
     <module>camel-aws2-ecs-starter</module>
     <module>camel-aws2-eks-starter</module>
     <module>camel-aws2-mq-starter</module>
+    <module>camel-aws2-msk-starter</module>
     <module>camel-aws2-translate-starter</module>
     <module>camel-azure-starter</module>
     <module>camel-barcode-starter</module>
diff --git a/tooling/camel-spring-boot-dependencies/pom.xml b/tooling/camel-spring-boot-dependencies/pom.xml
index d597552..6cd662e 100644
--- a/tooling/camel-spring-boot-dependencies/pom.xml
+++ b/tooling/camel-spring-boot-dependencies/pom.xml
@@ -438,6 +438,11 @@
       </dependency>
       <dependency>
         <groupId>org.apache.camel.springboot</groupId>
+        <artifactId>camel-aws2-msk-starter</artifactId>
+        <version>${project.version}</version>
+      </dependency>
+      <dependency>
+        <groupId>org.apache.camel.springboot</groupId>
         <artifactId>camel-aws2-translate-starter</artifactId>
         <version>${project.version}</version>
       </dependency>
@@ -2028,6 +2033,11 @@
       </dependency>
       <dependency>
         <groupId>org.apache.camel</groupId>
+        <artifactId>camel-aws2-msk</artifactId>
+        <version>3.1.0-SNAPSHOT</version>
+      </dependency>
+      <dependency>
+        <groupId>org.apache.camel</groupId>
         <artifactId>camel-aws2-translate</artifactId>
         <version>3.1.0-SNAPSHOT</version>
       </dependency>
diff --git a/components-starter/camel-aws2-mq-starter/src/main/java/org/apache/camel/component/aws2/mq/springboot/MQ2ComponentConfiguration.java b/components-starter/camel-aws2-msk-starter/src/main/java/org/apache/camel/component/aws2/msk/springboot/MSK2ComponentConfiguration.java
similarity index 74%
copy from components-starter/camel-aws2-mq-starter/src/main/java/org/apache/camel/component/aws2/mq/springboot/MQ2ComponentConfiguration.java
copy to components-starter/camel-aws2-msk-starter/src/main/java/org/apache/camel/component/aws2/msk/springboot/MSK2ComponentConfiguration.java
index 812763c..c234255 100644
--- a/components-starter/camel-aws2-mq-starter/src/main/java/org/apache/camel/component/aws2/mq/springboot/MQ2ComponentConfiguration.java
+++ b/components-starter/camel-aws2-msk-starter/src/main/java/org/apache/camel/component/aws2/msk/springboot/MSK2ComponentConfiguration.java
@@ -14,35 +14,35 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.camel.component.aws2.mq.springboot;
+package org.apache.camel.component.aws2.msk.springboot;
 
 import javax.annotation.Generated;
-import org.apache.camel.component.aws2.mq.MQ2Operations;
+import org.apache.camel.component.aws2.msk.MSK2Operations;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 import software.amazon.awssdk.core.Protocol;
-import software.amazon.awssdk.services.mq.MqClient;
+import software.amazon.awssdk.services.kafka.KafkaClient;
 
 /**
  * The aws-mq is used for managing Amazon MQ instances.
  * 
  * Generated by camel-package-maven-plugin - do not edit this file!
  */
 @Generated("org.apache.camel.springboot.maven.SpringBootAutoConfigurationMojo")
-@ConfigurationProperties(prefix = "camel.component.aws2-mq")
-public class MQ2ComponentConfiguration
+@ConfigurationProperties(prefix = "camel.component.aws2-msk")
+public class MSK2ComponentConfiguration
         extends
             ComponentConfigurationPropertiesCommon {
 
     /**
      * Whether to enable auto configuration of the aws2-mq component. This is
      * enabled by default.
      */
     private Boolean enabled;
     /**
      * The AWS MQ default configuration
      */
-    private MQ2ConfigurationNestedConfiguration configuration;
+    private MSK2ConfigurationNestedConfiguration configuration;
     /**
      * Amazon AWS Access Key
      */
@@ -52,7 +52,7 @@ public class MQ2ComponentConfiguration
      */
     private String secretKey;
     /**
      * The region in which MQ client needs to work
      */
     private String region;
     /**
@@ -72,12 +72,12 @@ public class MQ2ComponentConfiguration
      */
     private Boolean lazyStartProducer = false;
 
-    public MQ2ConfigurationNestedConfiguration getConfiguration() {
+    public MSK2ConfigurationNestedConfiguration getConfiguration() {
         return configuration;
     }
 
     public void setConfiguration(
-            MQ2ConfigurationNestedConfiguration configuration) {
+            MSK2ConfigurationNestedConfiguration configuration) {
         this.configuration = configuration;
     }
 
@@ -121,38 +121,37 @@ public class MQ2ComponentConfiguration
         this.lazyStartProducer = lazyStartProducer;
     }
 
-    public static class MQ2ConfigurationNestedConfiguration {
-        public static final Class CAMEL_NESTED_CLASS = org.apache.camel.component.aws2.mq.MQ2Configuration.class;
+    public static class MSK2ConfigurationNestedConfiguration {
+        public static final Class CAMEL_NESTED_CLASS = org.apache.camel.component.aws2.msk.MSK2Configuration.class;
         /**
          * Amazon AWS Access Key
          */
         private String accessKey;
         /**
          * To use a existing configured AmazonMQClient as client
          */
-        private MqClient amazonMqClient;
+        private KafkaClient mskClient;
         /**
-         * The operation to perform. It can be
-         * listBrokers,createBroker,deleteBroker
+         * The operation to perform
          */
-        private MQ2Operations operation;
+        private MSK2Operations operation;
         /**
          * To define a proxy host when instantiating the MQ client
          */
         private String proxyHost;
         /**
          * To define a proxy port when instantiating the MQ client
          */
         private Integer proxyPort;
         /**
          * To define a proxy protocol when instantiating the MQ client
          */
         private Protocol proxyProtocol = Protocol.HTTPS;
         /**
          * The region in which MQ client needs to work. When using this
          * parameter, the configuration will expect the capitalized name of the
          * region (for example AP_EAST_1) You'll need to use the name
          * Regions.EU_WEST_1.name()
          */
         private String region;
         /**
@@ -168,19 +167,19 @@ public class MQ2ComponentConfiguration
             this.accessKey = accessKey;
         }
 
-        public MqClient getAmazonMqClient() {
-            return amazonMqClient;
+        public KafkaClient getMskClient() {
+            return mskClient;
         }
 
-        public void setAmazonMqClient(MqClient amazonMqClient) {
-            this.amazonMqClient = amazonMqClient;
+        public void setMskClient(KafkaClient mskClient) {
+            this.mskClient = mskClient;
         }
 
-        public MQ2Operations getOperation() {
+        public MSK2Operations getOperation() {
             return operation;
         }
 
-        public void setOperation(MQ2Operations operation) {
+        public void setOperation(MSK2Operations operation) {
             this.operation = operation;
         }
 
@@ -14,35 +14,35 @@
 
 /**
- * The aws-mq is used for managing Amazon MQ instances.
+ * The aws2-msk is used for managing Amazon MSK
  * 
  * Generated by camel-package-maven-plugin - do not edit this file!
@@ -14,35 +14,35 @@
 
     /**
-     * Whether to enable auto configuration of the aws2-mq component. This is
+     * Whether to enable auto configuration of the aws2-msk component. This is
      * enabled by default.
      */
@@ -14,35 +14,35 @@
     private Boolean enabled;
     /**
-     * The AWS MQ default configuration
+     * The AWS MSK default configuration
      */
@@ -52,7 +52,7 @@ public class MQ2ComponentConfiguration
     private String secretKey;
     /**
-     * The region in which MQ client needs to work
+     * The region in which MSK client needs to work
      */
     private String region;
@@ -121,38 +121,37 @@ public class MQ2ComponentConfiguration
         private String accessKey;
         /**
-         * To use a existing configured AmazonMQClient as client
+         * To use a existing configured AWS MSK as client
          */
@@ -121,38 +121,37 @@ public class MQ2ComponentConfiguration
         /**
-         * To define a proxy host when instantiating the MQ client
+         * To define a proxy host when instantiating the MSK client
          */
         private String proxyHost;
@@ -121,38 +121,37 @@ public class MQ2ComponentConfiguration
         private String proxyHost;
         /**
-         * To define a proxy port when instantiating the MQ client
+         * To define a proxy port when instantiating the MSK client
          */
         private Integer proxyPort;
@@ -121,38 +121,37 @@ public class MQ2ComponentConfiguration
         private Integer proxyPort;
         /**
-         * To define a proxy protocol when instantiating the MQ client
+         * To define a proxy protocol when instantiating the MSK client
          */
         private Protocol proxyProtocol = Protocol.HTTPS;
@@ -121,38 +121,37 @@ public class MQ2ComponentConfiguration
         private Protocol proxyProtocol = Protocol.HTTPS;
         /**
-         * The region in which MQ client needs to work. When using this
-         * parameter, the configuration will expect the capitalized name of the
-         * region (for example AP_EAST_1) You'll need to use the name
-         * Regions.EU_WEST_1.name()
+         * The region in which MSK client needs to work. When using this
+         * parameter, the configuration will expect the lowercase name of the
+         * region (for example ap-east-1) You'll need to use the name
+         * Region.EU_WEST_1.id()
          */
         private String region;